This function takes 24 hourly files from the same day and variable and converts them to a daily format. You have the choice of four different aggregation methods: min, max, mean, and sum.
metnordic_aggregate(
directory,
variable,
method,
day,
outpath,
overwrite = TRUE,
verbose = TRUE
)String: Path to the source files (as downloaded by metnordic_download() or metnordic_download_daterange())
String: MET Nordic variable to aggregate (ie. "precipitation_amount", (see more))
String: method of aggregation ("mean", "min", "max", "sum")
String: day to convert ("YYYYMMDD" format, ie. "20150901")
String: path to directory of to be created files
Logical: overwrite existing file?
Logical: plot map?
String: path to written file
This function is designed to take input from metnordic_download() and
provides input for metnordic_merge()
Code largely adapted from this handy guide: (link) from Pat Bartlein, bartlein@uoregon.edu
# TODO