This function builds the URL queries for downloading MET Nordic data through
the OPENDAP protocol. The requirements for this function to work are the
bounding coordinates as divined by function metnordic_coordwindow(), the
variables of interest, the starting and ending dates and the desired grid
resolution. The results of this function can be downloaded when passed to
metnordic_download().
metnordic_buildquery(
bounding_coords,
mn_variables,
fromdate,
todate,
grid_resolution = 1,
dataset = "reanalysis",
verbose = FALSE
)as passed by metnordic_coordwindow()
MET Nordic variables (see documentation)
ie. "2019-01-01 00:00:00"
ie. "2020-12-31 23:00:00"
an integer, ie. 3 for 3x3 km grid.
either 'reanalysis' for the re-run archive, 'operational' for the operational archive, 'ltc' for the EXPERIMENTAL long term consistent product or 'continuous' to source from all, depending on date range.
print to console?
character vector of all the OPENDAP URLs to download.
# TODO