This function converts Meteo data from MET Nordic into a SWAP-compatible
format. Note: need to use metnordic_csv() to create proper input for this
function.
swap_metnordic(dldir, name, outpath, timescale = "daily", verbose = FALSE)download directory containing data and metadata, as generated by metnordic_extract()
name of the extracted point, as defined in metnordic_extract()
desired location for the swap .met file to be written
"daily" or "hourly". (hourly not supported yet)
logical, print some stuff to console
path to written .met file