Combines climate data from Norsk Klima Service Center and observed data to produce "Thermopluviograms".
thermopluviogram(
modelled_climate,
observed_pr,
observed_tm,
outpath,
location,
ref_startdate,
ref_enddate,
obs_startdate,
obs_enddate,
verbose = TRUE,
chosen_model_runs = NULL,
experiments = c("hist", "rcp45", "rcp85"),
left_yaxis_only = FALSE,
fixed_axis = TRUE,
axis_font_size = 7,
yaxisrange = c(800, 1100),
xaxisrange = c(4.5, 8.5),
xlab = "Mean Annual Temperature (°C)"
)filepath of climate files (i.e. "Climate_Data/Modelled/")
filepath of observed precipitation data (.csv)
filepath of the observed mean temperature data (.csv)
outpath for plotting
location of plot (is used for file naming) (string)
reference period start (ie."1971-01-01")
reference period d end (ie. "2005-12-31")
observation period start (ie. "2041-01-01")
observation period end (ie. "2070-12-31")
print progress?
Names of the models to color as blue
Experiments to generate (ie. c("hist", "rcp45","rcp85"))
If set to true, only the historical plot axis will be labeled (This is so the three plots can be placed next to each other in a figure)
use a fixed axis range when plotting? (boolean)
Font size (Integer)
y axis range (ie. c(800,1100), mm)
x axis range (ie. c(4.5, 8.5), Celsius)
x axis label. (ie. "Mean Annual Temperature)", u00B0 is degree symbol)
path to generated files
https://www.senorge.no/PrecTempMap
todo: describe file struture
Generates thermopluviograms and extreme rain index plots from NVE not flexible. only works with current source data structure.
Date: 01.06.2022 Author: Moritz Shore