NOTE: this function has a few requirements to work, please see below.
Arguments
- buildR_dir
(string) path to SWATbuildR project directory (containing the 'data/*' subdirectory)
- directory
(string) directory where to save/load the generated HRU plots to/from. (will be saved in a sub-directory 'hru_report/')
- RERENDER
(logical) re-generate the HRU plots?
- verbose
(logical) print status?
Details
This function only works with SWATbuildR output, along side with a generated
land_connections_as_lines.shpfile which can be generated using this code.The land use theme is set up for my specific catchment. If you need to add to this theme then please send a pull request with the additional legend entries.