This function lets you combine the hourly files downloaded by
download_metnordic() into single files. Note, these files are separate
per variable!
metnordic_merge_hourly(
folderpath,
variable,
outpath,
n_cores = NULL,
overwrite = FALSE,
verify = FALSE,
verbose = FALSE
)(String) folder where individual files are located
(String) MET Nordic variable to combine
(String) folder where to write the file
(Integer) Number of cores to use for parallel processing (Defaults to max - 2)
(Boolean) overwrite existing file?
(Boolean) an optional check to see if all files to be merged are incremental (Recommended!)
(Boolean) print status?
path of written file